function  newbreaks = EditBreaks(breaks)
% newbreaks = EditBreaks(breaks): Pops a input dialog box to edit breaks
% Breajk Structure:
% (1) Decimal year of break
% (2) 0 for regular break, t+tau of exponent, tau for log
% (3:5) Aproiori NEU velocity for break only if log
% (6) Hidden type: 0 regular, 1 exp , 2 log, 3 eq file earthquake.
%
if isempty(breaks)
    disp('No breaks to edit');
    newbreaks = breaks;
    return
end;
%
% Get number of breaks
nb = length(breaks(:,1)); num_lines = 1;
dlg_title = 'Edit Breaks';
% Make up the default lines
def = []; prompt = [];
for i = 1:nb
    if breaks(i,2) == 0 
        def = strvcat(def,sprintf('BR %4d %2d %2d %2d %2d\n',YrToDate(breaks(i,1),5)));
        prompt = strvcat(prompt,['Break ', num2str(i)]);
    elseif breaks(i,2) > breaks(i,1)
        tau = (breaks(i,2)-breaks(i,1))*365;
        def = strvcat(def,sprintf('EX %4d %2d %2d %2d %2d %3.1f\n',YrToDate(breaks(i,1),5),tau));
        prompt = strvcat(prompt,['Exponent ', num2str(i)]);
    else
        tau = breaks(i,2)*365;
        if i == 1 && breaks(1,3) == 0 
            def = strvcat(def,sprintf('LN %4d %2d %2d %2d %2d %3.1f\n',YrToDate(breaks(i,1),5),tau));
        else
            def = strvcat(def,sprintf('LN %4d %2d %2d %2d %2d %3.1f %5.2f %5.2f %5.2f Vel mm/yr\n',YrToDate(breaks(i,1),5),tau,breaks(i,[3:5])));
        end
        prompt = strvcat(prompt,['Logarithmic ', num2str(i)]);
    end
end
def = cellstr(def); prompt = cellstr(prompt);
answer  = inputdlg(prompt,dlg_title,num_lines,def,'on');
answer = upper(answer); 
if ~isempty(answer)   % If answer is empty it means cancel was hit
    for i = 1:nb
        type = answer{i}([1:2]);
        la = length(answer{i});
        if type == 'BR'
            date = sscanf(answer{i}([3:la]),'%d');
            breaks(i,1) = DateToYr(date,5); breaks(i,2) = 0; % Do not change break type
        elseif type == 'EX'
            date = sscanf(answer{i}([3:la]),'%d');
            breaks(i,1) = DateToYr(date,5); breaks(i,2) = breaks(i,1)+date(6)/365; breaks(i,6) = 1;
        elseif type == 'LN'
            date = sscanf(answer{i}([3:la]),'%f');
            % Make sure that the second break argument is not exactly zero
            % (or else it will look like a simple break).
            breaks(i,1) = DateToYr(date,5); breaks(i,2) = max(date(6),0.01)/365; breaks(i,6) = 2;
            if  length(date)==9 ; breaks(i,[3:5]) = date([7:9]); end

        end
    end
end
newbreaks = breaks;

            
            

            
            

