function out = EstResult(name, Comptext, wrms, nrms, nd, ...
               anpar, sapar, exprt, breaks, soln, cov)
% Function to write a string containing \n's to output the results
out = sprintf('Detrend of %s %s \n', name, Comptext); 
out = [out, sprintf('WRMS: %7.2f mm NRMS:%6.2f #: %5d data\n', wrms, nrms, nd)];
out = [out, sprintf('Mean                      %10.2f +- %6.2f mm   \n', soln(1), sqrt(cov(1,1)))];
out = [out, sprintf('Rate                      %10.2f +- %6.2f mm/yr\n', soln(2), sqrt(cov(2,2)))];
nc = 2;
if anpar
    out = [out, sprintf('Annual Cos                %10.2f +- %6.2f mm   \n', soln(nc+1),sqrt(cov(nc+1,nc+1)))];
    out = [out, sprintf('Annual Sin                %10.2f +- %6.2f mm   \n', soln(nc+2),sqrt(cov(nc+2,nc+2)))];
    nc = nc + 2;
end
if sapar
    out = [out, sprintf('SemiAnnual Cos            %10.2f +- %6.2f mm   \n', soln(nc+1),sqrt(cov(nc+1,nc+1)))];
    out = [out, sprintf('SemiAnnual Sin            %10.2f +- %6.2f mm   \n', soln(nc+2),sqrt(cov(nc+2,nc+2)))];
    nc = nc + 2;
end

% Now write out breaks
if isempty(breaks), lbrk = 0; else lbrk = length(breaks(:,1)); end  

spvo = 0;

for i = 1:lbrk
    % get the fractional part of the year and convert to month and day
    bdate = YrToDate(breaks(i,1),5); 
    if breaks(i,2) == 0 && breaks(i,6) == 0  % | abs(breaks(i,2)-breaks(i,1)) < 0.002   % Either zero or < 1day
        out =[out, sprintf('Break %4d %2d %2d %2d %2d           %10.2f +- %6.2f mm\n',...
        bdate([1:5]),soln(nc+1),sqrt(cov(nc+1,nc+1)))] ;
        nc = nc + 1;
    elseif breaks(i,2) == 0 && breaks(i,6) == 3 % Earthquake break with just an offset
        out =[out, sprintf('EQBrk %4d %2d %2d %2d %2d           %10.2f +- %6.2f mm\n',...
        bdate([1:5]),soln(nc+1),sqrt(cov(nc+1,nc+1)))] ;
        nc = nc + 1;
    elseif breaks(i,2) > breaks(i,1)
        % If this is first exponential break, save time for later use
        if spvo == 0 
            spvo = breaks(i,1);
            ncsvp = nc+1; isvp = i;
            nle = nc ;
            lnbrks = 0;
        end
        lnbrks = lnbrks + 1 ;
        tau = (breaks(i,2)-breaks(i,1))*365;
        out =[out, sprintf('Offst %4d %2d %2d %2d %2d Tau %3.1f %10.2f +- %6.2f mm\n',...
                    bdate([1:5]),tau, soln(nc+1),sqrt(cov(nc+1,nc+1)))] ;
        out =[out, sprintf('Expon %4d %2d %2d %2d %2d Tau %3.1f %10.2f +- %6.2f mm\n',...
                    bdate([1:5]),tau, soln(nc+2),sqrt(cov(nc+2,nc+2)))] ;
        nc = nc + 2;
        nle = nle +2 ;
        if exprt
            out =[out, sprintf('dRate %4d %2d %2d %2d %2d Tau %3.1f %10.2f +- %6.2f mm/yr\n',...
                    bdate([1:5]),tau, soln(nc+1),sqrt(cov(nc+1,nc+1)))] ;
            nc = nc + 1;
            nle = nle + 1;
        end
    else
        % If this is first log break, save time for later use
        if spvo == 0 
            spvo = breaks(i,1);
            ncsvp = nc+1; isvp = i;
            nle = nc ;
            lnbrks = 0;
        end
        lnbrks = lnbrks + 1 ;
        tau = breaks(i,2)*365;
        out =[out, sprintf('OffLn %4d %2d %2d %2d %2d dOf %3.1f %10.2f +- %6.2f mm\n',...
                    bdate([1:5]),tau, soln(nc+1),sqrt(cov(nc+1,nc+1)))] ;
        out =[out, sprintf('Log   %4d %2d %2d %2d %2d dOf %3.1f %10.2f +- %6.2f mm\n',...
                    bdate([1:5]),tau, soln(nc+2),sqrt(cov(nc+2,nc+2)))] ;
        nc = nc + 2;
        nle = nle +2 ;
        if exprt
            out =[out, sprintf('dRate %4d %2d %2d %2d %2d dOf %3.1f %10.2f +- %6.2f mm/yr\n',...
                    bdate([1:5]),tau, soln(nc+1),sqrt(cov(nc+1,nc+1)))] ;
            nc = nc + 1;
            nle = nle + 1; 
        end  
    end
end

%% Output position and velocity as function of time
%
pvo =  get(findobj(gcf,'Tag','PVOTS'),'Value');
if pvo == 1 && spvo > 0
    % Creat output file 
    pvofile = strcat('PVO_',name(1:4),'_',Comptext(1:1),'.dat');
    [fir, message] = fopen(pvofile,'w');
    fprintf(fir,'Year MM DD  HR MN   dT (days)   Offset (mm)    +-    dO/dt (mm/yr)   +-     Rho OR\n');
    enddy = (2010-breaks(isvp,1))*365.25;
    % Copy covariance elements needed
    CVlog = cov(ncsvp:nle,ncsvp:nle); Sollog = soln(ncsvp:nle);
    % Now loop over times
    for dt = 1.e-6:7:enddy
        yrd = spvo + dt/365.25 ; odate = YrToDate(yrd,5);
        % Generate the partials matrix
        apart = zeros(2,nle-ncsvp+1);
        np = 0;
        for i = isvp:isvp+lnbrks-1
            dtl = (yrd - breaks(i,1)); % Time is in years (break date 
                                       % and time constant are years too.
            np = np+1;
            apart(1,np) = 1; apart(2,np) = 0;
            % if offset is not well known, then don't include in position
            if CVlog(np,np) > 100 || dtl <= 0
                apart(1,np) = 0; 
            end
            np = np+1 ; % log or exponent itself
            if ( dtl >= 0 ) 
                if breaks(i,2) > breaks(i,1)
                    tau = (breaks(i,2)-breaks(i,1));
                    apart(1,np) = (1-exp(-dtl/tau));
                    apart(2,np) = exp(-dtl/tau)/tau;
                else
                    apart(1,np) = log(1+dtl/abs(breaks(i,2)));
                    apart(2,np) = 1.0/(abs(breaks(i,2)) * (1+dtl/abs(breaks(i,2))));
                end
            else
               apart(1,np) = 0;
               apart(2,np) = 0;
            end
        end
        DPV = apart*Sollog;
        CovPV = apart*CVlog*apart';
        fprintf(fir,' %4d %2.2d %2.2d  %2.2d %2.2d %10.1f %10.2f %10.2f  %10.2f %10.2f %8.4f\n', ...
            odate, dt, DPV(1), sqrt(CovPV(1,1)), DPV(2), sqrt(CovPV(2,2)), CovPV(1,2)/sqrt(CovPV(1,1)*CovPV(2,2)));
    end
    fclose(fir);
end
            
            
            
            
        
    
    
    
    
    
