function [ensrms, ensnames, err] = ReadENFile(nrms_sort, ensfile)
% ReadENFile: Reads an ensum file and returns list of horzontal/vertical
% RMS and Site names
%
ensrms = []; ensnames = []; err = 0;
%
% Try to open ensfile
[fid, message] = fopen(ensfile,'r');
if fid < 0
    errordlg(strcat('Error opening--',ensfile,' :-',message))
    err = -1;
    return
end
%
% Now start reading the ENSfile
OK = 1;
while OK
	line = fgetl(fid);
	if isstr(line)
		if length(line) == 0; line = ' X'; end
		if line(1:1) ~= ' '
            sn = line(1:8);
            cmp = strcat(line(17:17)) ;  % Assumes standard formating for file
            % Remove any overflow stars by replacing with 9
            edline = strrep(line,'*','9');
			[A, count, errmsg, indx] = sscanf(edline(18:length(line)),'%f');
			if count >= 12 
                if cmp == 'N', wrms(1) = A(9); nrms(1) = A(10); end
                if cmp == 'E', wrms(2) = A(9); nrms(2) = A(10); end
                if cmp == 'U', wrms(3) = A(9); nrms(3) = A(10); 
                    % Once we read the U component save information
                    if nrms_sort
                       ensrms = [ensrms ; [sqrt(nrms(1)^2+nrms(2)^2) nrms(3) ...
                                           max([nrms(1) nrms(2) nrms(3)])] ];
                    else
                       ensrms = [ensrms ; [sqrt(wrms(1)^2+wrms(2)^2) wrms(3) ...
                                           max([wrms(1) wrms(2) wrms(3)])] ];
                    end
                    ensnames = [ensnames; sn];
                end
			end	
		end
	else
		OK = 0;
	end
end         % Looping over lines in file.

fclose(fid);

