function [eqeq eqrn] = ReadEq(fid,eqfile)
% ReadEq: Function to read a Globk EQ file and return structures with EQ
% and rename information
%
%fid = fopen(eqfile,'r');
fprintf('Read EQ file %s\n',eqfile)
eqeq = []; eqrn = []; meq = 20; % mrn = 200;
seq_code = []; 
seq_par=zeros(5,meq); seq_cos=zeros(6,meq); seq_log=zeros(7,meq);seq_exp=zeros(7,meq);
srn_n1 = []; srn_n2 = []; srn_cen = [] ; srn_yr = [];

% Loop over file until EOF found
OK = 1;
while OK
    line = fgetl(fid);
    if ischar(line)
        % Line is OK so continue; see if empty
        if isempty(line) || length(findstr(line,' ')) == length(line)  % Latter is all blank
            line = 'X';  % Make into comment (avoids error of checking null string
        else % Remove any end of line comments
            pc = findstr('!',line);
            if ~isempty(pc)
                line(pc(1):length(line)) = ' ';
            end
        end
        if strcmp(line(1:1),' ')
            % First character is blank, so decode line
            [token count mess ni] = sscanf(line,'%s',1);
            if length(token) < 4 
                fprintf('Bad line in EQ file: Option %s Line:%s\n',token, line)
                count = 0;
            end
            if count == 1 
                utoken = upper(token(1:4));
                switch utoken
                    case 'EQ_D'
                        % Get the EQ code
                        [eq_code count mess nj] = sscanf(line(ni:length(line)),'%s',1);
 
                        ni = ni + nj ; 
                        [eq_par count mess nj] = sscanf(line(ni:length(line)),'%f',9);
                        % Add this to list
                        [ieq seq_code] = FindEQc(eq_code,seq_code);
                        % Save the parameters
                        if eq_par(5) < 500 
                            if eq_par(5) < 50 
                                eq_par(5) = eq_par(5)+2000;
                            else
                                eq_par(5) = eq_par(5)+1900;
                            end
                        end
                        decyr = DateToYr(eq_par(5:9),5);
                        seq_par(:,ieq) =[ eq_par(1:4)' decyr];
                        seq_cos(:,ieq) = zeros(6,1);
                        seq_exp(:,ieq) = zeros(7,1);
                        seq_log(:,ieq) = zeros(7,1);
                    case 'EQ_C'
                        [eq_code count mess nj] = sscanf(line(ni:length(line)),'%s',1);
                        ni = ni + nj ; 
                        [eq_cose count mess nj] = sscanf(line(ni:length(line)),'%f',6);
                        [ieq seq_code] = FindEQc(eq_code,seq_code);
                        seq_cos(:,ieq) = eq_cose';
                    case 'EQ_L'
                        [eq_code count mess nj] = sscanf(line(ni:length(line)),'%s',1);
                        ni = ni + nj ; 
                        [eq_log count mess nj] = sscanf(line(ni:length(line)),'%f',7);
                        [ieq seq_code] = FindEQc(eq_code,seq_code);
                        seq_log(:,ieq) = eq_log';

                    case 'EQ_E'   % eq_exp command which is not implemented in globk
                        [eq_code count mess nj] = sscanf(line(ni:length(line)),'%s',1);
                        ni = ni + nj ; 
                        [eq_exp count mess nj] = sscanf(line(ni:length(line)),'%f',7);
                        [ieq seq_code] = FindEQc(eq_code,seq_code);
                        seq_exp(:,ieq) = eq_exp';
                    case 'RENA'
                        [rn_n1 count mess nj] = sscanf(line(ni:length(line)),'%s',1);
                        ni = ni + nj;
                        [rn_n2 count mess nj] = sscanf(line(ni:length(line)),'%s',1);
                        ni = ni + nj;
                        [rn_dates count mess nj] = sscanf(line(ni:length(line)),'%f',10);
                        if count == 0  % Must have string for hfile name
                            % Try to read again
                            [rn_cen count mess nj] = sscanf(line(ni:length(line)),'%s',1);
                            if count == 0   % Test case when nothing left on line
                                rn_cen = '@';
                            end
                            ni = ni + nj;
                            [rn_dates count mess nj] = sscanf(line(ni:length(line)),'%f',10);
                        else
                            rn_cen = '@';
                        end
                        if count == 0
                            rn_dates(1) = 1900; rn_dates(2:3) = 1; rn_dates(4:5) = 0;  
                            rn_dates(6) = 2100; rn_dates(7:8) = 1; rn_dates(9:10) = 0;
                        elseif count < 10 
                            rn_dates(6) = 2100; rn_dates(7:8) = 1; rn_dates(9:10) = 0;
                        end
                        if rn_dates(1) < 50 , rn_dates(1)=rn_dates(1)+1900; end
                        if rn_dates(6) < 50 , rn_dates(6)=rn_dates(6)+1900; end                            
                        rns = DateToYr(rn_dates(1:5),5); rne = DateToYr(rn_dates(6:10),5);
                        srn_n1 = strvcat(srn_n1,rn_n1); 
                        try
                            srn_n2 = [srn_n2 ; rn_n2];
                        catch ME                            
                            fprintf('Error in Rename line: %s\n',line);
                        end

                     
                        if isempty(srn_cen)
                            srn_cen = {rn_cen};
                        else
                            srn_cen = [srn_cen, rn_cen];
                        end
                        %  srn_cen = strvcat(srn_cen,  rn_cen);
                        srn_yr = [srn_yr ; rns rne];
                end
            end
            % We had a valid line; now see what we should with it.        

        end
    else
        % EOF reached
        OK = 0 ;
    end
end

% Summarize what was found
neq = size(seq_code,1);
nrn = size(srn_n1,1);
fprintf('%d Earthquakes and %d renames found in %s\n',neq, nrn, eqfile)

eqrn = struct('RN_N1',srn_n1,'RN_N2',srn_n2,'RN_CN',srn_cen, 'RN_YR',srn_yr);
eqeq = struct('EQ_CODE',seq_code,'EQ_PAR',seq_par,'EQ_COS',seq_cos,'EQ_LOG',seq_log,'EQ_EXP',seq_exp);




        
