function [vels,names] = ReadVel(velinf)
% ReadVel: Function to read GLOBK style velocity field

%
vels = []; names = [];
% Open the input file
file = velinf.FileName;
[fid,message] = fopen(file,'r');
if fid == -1
    mess = ['Error opening ',file,' : ',message] ;
    errordlg(mess);
    return
end

% Check the options above error limits
sighlim = velinf.SigHLim; sigvlim = velinf.SigVLim;
sighscl = velinf.SigHScl; sigvscl = velinf.SigVScl;
% Get if values to be displayed.  This impacts how the sigma magnitude
% limits are checked.  If on H display, V sigmas are ignored; When both
% are displayed, passing either will lead to display.
displayh = velinf.DisplayH; displayv = velinf.DisplayV; 
 
%
% read down the file
OK = 1;
while OK
	line = fgetl(fid);
	if ischar(line) 
		if isempty(line) || length(line) < 10
            line = 'X'; 
        end
        %line
		if line(1:1) == ' '
			[A, count, errmsg, indx] = sscanf(line,'%f');
			if count == 12 % Number of entries on valid line
                % Now see if values are OK to be added (sigmas limit test)
                hOK = 1; vOK = 1;
                if displayh && A(7) > sighlim || A(8) > sighlim , hOK = 0; end
                if displayv && A(12) > sigvlim , vOK = 0; end
                % Make sure that the sigmas are not zero.  Print warning
                % message and set sigma to 0.1 mm/yr
                if A(7) <= 0 || A(8) <= 0 || A(12) <= 0,
                    fprintf('**WARNING** Velocity at %s hase zero sigmas, setting to 0.1 mm/yr\n', ...
                        line(indx:indx+7));
                    A(7) = 0.1 ; A(8) = 0.1; A(12) = 0.1;
                end
                if A(1) < 0 
                    A(1) = A(1) + 360.0;
                end
                
                if hOK && vOK
    				vels = [vels;A];
		    		name = line(indx:indx+7);
			    	names = [names;name];
                end
            else  % See if New PBO Velocity field
                name = strcat(line(2:5),'_GPS');
                % See if we used this name before. If so add number to end
                n = 0;
                for i = 1:size(names,1)
                    if findstr(name(1:4),names(i,1:4)), n = n+1; end
                end
                if n > 0 
                    name = sprintf('%s_G%2.2d',name(1:4),n);
                end
             
                [B, count, errmsg, indx] = sscanf(line(23:length(line)),'%f');
                if count == 28
                    % Now see if values are OK to be added (sigmas limit test)
                    A = zeros(12,1);
                    A(1) = B(7); A(2) = B(6); 
                    A(3) = B(19)*1000; A(5) = B(19)*1000;
                    A(4) = B(18)*1000; A(6) = B(18)*1000;
                    A(7) = B(22)*1000; A(8)=B(21)*1000; A(9) = B(24);
                    A(10) = B(20)*1000; A(11) = B(20)*1000;
                    A(12) = B(23)*1000;
                    hOK = 1; vOK = 1;
                    if displayh && A(7) > sighlim || A(8) > sighlim , hOK = 0; end
                    if displayv && A(12) > sigvlim , vOK = 0; end
                    % Make sure that the sigmas are not zero.  Print warning
                    % message and set sigma to 0.1 mm/yr
                    if A(7) <= 0 || A(8) <= 0 || A(12) <= 0,
                        fprintf('**WARNING** Velocity at %s hase zero sigmas, setting to 0.1 mm/yr\n', ...
                            line(indx:indx+7));
                        A(7) = 0.1 ; A(8) = 0.1; A(12) = 0.1;
                    end
                
                    if hOK && vOK
                        vels = [vels;A];
                        names = [names;name];
                    end
                end
			end	
		end
	else
		OK = 0;
	end
end

% Remove the .... from the names
%for i = 1:size(names,1)
%    names(i,:) = strrep(names(i,:),'....','    ');
%end

num = length(vels)/12;
vels = reshape(vels,12,num);
% Scale the errors before return
vels(7,:) = vels(7,:)*sighscl; vels(8,:) = vels(8,:)*sighscl;
vels(12,:) = vels(12,:)*sigvscl;

fclose(fid);
