function azdeg = SelectProfAz
% SelectProfAz: Graphic routine to select the azimith of profile mapping
%
% Since we have to the rrbox from screen coordinates, get some information
% about current figure and axes
scnsize = get(0,'ScreenSize');
figsize = get(gcf,'Position');
axesize = get(gca,'Position');  % Could get CurrentAxes from gcf
llsize = [get(gca,'Xlim') get(gca,'Ylim')];
asprat = get(gca,'DataAspectRatio');
% Based on the aspect ratio, find the actual coordinates coordinates
% covered by the axesize.
ratio = (llsize(2)-llsize(1))*asprat(2)/(llsize(4)-llsize(3));
if ratio > 1,   % Longitude covers the full pixel range
    xoff = figsize(1)+axesize(1); xscl = (llsize(2)-llsize(1))/axesize(3); 
    % For Latitude, compute height of axes
    dyht = (axesize(4)-axesize(4)/ratio)/2;
    yoff = figsize(2)+axesize(2)+dyht; yscl=(llsize(4)-llsize(3))/(axesize(4)/ratio);
else
    dxwd = (axesize(3)-axesize(3)*ratio)/2;
    xoff = figsize(1)+axesize(1)+dxwd; xscl=(llsize(2)-llsize(1))/(axesize(3)*ratio); 
    yoff = figsize(2)+axesize(2); yscl=(llsize(4)-llsize(3))/axesize(4);
end
xin=llsize(1); yin=llsize(3);
% Construct the mapping array
pix2ll = [xoff xscl xin ; yoff yscl yin];

% setup the figure button up function to see user data to 1
set(gcf,'WindowButtonUpFcn','buttonup');

% wait for button pres
figure(gcf);
k = waitforbuttonpress;
llint = GetLL(gcf,pix2ll);
hl = plot(llint([1 1]),llint([2 2]),'bx-','EraseMode','xor','MarkerSize',10);
set(gcf,'UserData',0);
done = 0;
while ~done 
    done = get(gcf,'UserData');
    llfin = GetLL(gcf,pix2ll);
    set(hl,'Xdata',[llint(1) llfin(1)]);
    set(hl,'Ydata',[llint(2) llfin(2)]);
    drawnow;
end
% Convert the line to a solid line and start on the box
set(hl,'LineStyle','-','LineWidth',2); drawnow;
profll = [llint; llfin];
%
% Now compute the azimuth of the line
dtr = pi/180;
cosb = sin(profll(2,2)*dtr)*sin(profll(1,2)*dtr) + ...
    cos(profll(2,2)*dtr)*cos(profll(1,2)*dtr)*cos((profll(2,1)-profll(1,1))*dtr);
plr = acos(cosb); plkm = plr*6371.;
% Now compute the azimith of the profile
sa = cos(profll(2,2)*dtr)*sin((profll(2,1)-profll(1,1))*dtr)/sin(plr);
ca = (sin(profll(2,2)*dtr)-cos(plr)*sin(profll(1,2)*dtr))/ ...
    (sin(plr)*cos(profll(2,2)*dtr));
azdeg = atan2(sa,ca)/dtr;
%
fprintf(1,'Selected azimuth is %6.2f deg\n',azdeg);
azstr = num2str(azdeg,'%6.2f');
haz = findobj(gcf,'Tag','ProfAzIn'); set(haz,'String',azstr);

% Now remove the line from the plot after a 2-second pause
pause(2); delete(hl);


