function stats = WMean(velinp,nameinp);
% stats = WMean(velinp): Compute mean and statistics of selected stations
% stats returns #site WMean_N Sig M WRMS_N NRMS_N WMean_E SigE WRMS_E
% NRMS_E Wmean_U SigU WRMS_U NRMS_U
%
% Find the wmean for each component
stats = zeros(1,13);
for i = 1:3
    if i == 1, Vals = velinp(4,:); Sig = velinp(8,:);       % North
    elseif i == 2, Vals = velinp(3,:); Sig = velinp(7,:);   % East
    elseif i == 3, Vals = velinp(10,:); Sig = velinp(12,:); % Up
    end
    %
    % Form the weight vector
    num = length(Vals);
    w = 1./Sig.^2;
    Wmean = w*Vals'/sum(w);
    r = Vals - Wmean;
    if num > 1, nrms = sqrt(sum(r.^2.*w)/(num-1)); else chi = 1; end
    wrms = nrms*sqrt(num/sum(w));
    stats(1) = num; stats(2+4*(i-1)) = Wmean; stats(3+4*(i-1)) = wrms/sqrt(num);
    stats(4+4*(i-1)) = wrms; stats(5+4*(i-1)) = nrms;
end
% Pause before continuing
pause(2)
% Now output a new figure the results on it.
vtext = sprintf(['Offset Results from %d sites (right-click to remove)\n', ...
        'Comp         Wmean (mm)     WRMS  NRMS\n', ...
        'North   %6.2f +- %6.2f  %6.2f %6.3f\n', ...
        'East    %6.2f +- %6.2f  %6.2f %6.3f\n', ...
        'Height  %6.2f +- %6.2f  %6.2f %6.3f\n', ....
        'Site        NRes +-       ERes +-        URes +-\n'], stats);
for i = 1:num
    vtext = [vtext, sprintf('%s %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f\n', ...
            nameinp(i,:), velinp(4,i)-stats(2), velinp(8,i), ...
            velinp(3,i)-stats(6), velinp(7,i), ...
            velinp(10,i)-stats(10), velinp(12,i))];
end
% Pause before continuing
pause(2);
% Get size of current axes
szfg = get(gcf,'Position');
pos = [szfg(3)-325 szfg(4)-(6+stats(1))*13-3 325 (6+stats(1))*13+3];
              
hk = uicontrol('Parent',gcf, ...
	       'Units','pixels', ...
	       'Position',pos, ...
           'BackgroundColor',[1 1 0.78], ...
	       'String',vtext, ...
           'FontSize',9, ...
           'FontName','Courier', ...
           'HorizontalAlignment','left', ...
           'ButtonDownFcn','delete(gcbo)', ...
	       'Style','text', 'Enable','inactive',...
	       'Tag','OutResult2');
       
% Also output the results to the screen
fprintf(1,'--------------------------------------------------\n');
fprintf(1,'%s\n',vtext);

    
